;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "eldoc-box" "1.14.1"
  "Display documentation in childframe."
  '((emacs "27.1"))
  :url "https://github.com/casouri/eldoc-box"
  :commit "8c5104f06700b774b8af76d77a440e334fbc03e9"
  :revdesc "8c5104f06700"
  :authors '(("Yuan Fu" . "casouri@gmail.com"))
  :maintainers '(("Yuan Fu" . "casouri@gmail.com")))
